HarCapture

Struct HarCapture 

pub struct HarCapture { /* private fields */ }
Captures HTTP Archive (HAR) data for a page by listening to Chrome’s Network domain events. Start it via crate::Page::start_har_capture.

Example

let browser = Browser::launch_chrome(None).await?;
let page = browser.new_page().await?;

let har = page.start_har_capture().await?;
page.goto("https://example.com", WaitUntil::Load).await?;

let archive = har.export().await;
let json = serde_json::to_string_pretty(&archive)?;
std::fs::write("trace.har", json)?;

Implementations

Source

impl HarCapture

pub async fn start(&self) -> Result<()>

Listen to CDP Network events and accumulate HAR entries. Call this to start capturing. Events are processed in a background task until stop or the HarCapture is dropped.

pub async fn stop(&self) -> HarArchive

Stop the capture and return the complete HAR archive.

This drains any remaining pending requests (for requests that were sent but never received a response) and returns the full HAR.

pub async fn export(&self) -> HarArchive

Export the current HAR without stopping the capture.

pub async fn clear(&self)

Clear all captured entries and pending requests.