pub struct Locator { /* private fields */ }Expand description
A lazy handle to a DOM element identified by a CSS selector.
Locators are created with Page::locator and make the common
“find-then-act” pattern ergonomic and composable.
Example
let browser = Browser::launch().await?;
let page = browser.new_page().await?;
page.goto("https://example.com", WaitUntil::Load).await?;
// Locator API
page.locator("button#submit").click().await?;
page.locator("input[name=q]").type_text("hello").await?;
page.locator(".result").wait_for().await?;Implementations
Sourceimpl Locator
impl Locator
Sourcepub async fn type_text(&self, text: &str) -> Result<()>
pub async fn type_text(&self, text: &str) -> Result<()>
Type text into the element identified by this locator.
Sourcepub async fn wait_for(&self) -> Result<()>
pub async fn wait_for(&self) -> Result<()>
Wait until the element is present in the DOM (30 s default timeout).
Sourcepub async fn wait_for_timeout(&self, dur: Duration) -> Result<()>
pub async fn wait_for_timeout(&self, dur: Duration) -> Result<()>
Wait until the element is present with a custom timeout.
Sourcepub async fn inner_text(&self) -> Result<String>
pub async fn inner_text(&self) -> Result<String>
Get the inner text of the element.